OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Tasks" : "Tasques",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Heu creat el calendari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha suprimit el calendari {calendar}",
    "You deleted calendar {calendar}" : "Heu suprimit el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Heu actualitzat el calendari {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} ha restaurat el calendari {calendar}",
    "You restored calendar {calendar}" : "Heu restaurat el calendari {calendar}",
    "You shared calendar {calendar} as public link" : "Heu compartit el calendari {calendar} amb un enllaç públic",
    "You removed public link for calendar {calendar}" : "Heu suprimit l'enllaç públic del calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vós",
    "You shared calendar {calendar} with {user}" : "Heu compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha deixat de compartir el calendari {calendar} amb vós",
    "You unshared calendar {calendar} from {user}" : "Heu deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha deixat de compartir el calendari {calendar} amb si mateix",
    "You shared calendar {calendar} with group {group}" : "Heu compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Heu deixat de compartir el calendari {calendar} amb el grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha deixat de compartir el calendari {calendar} amb el grup {group}",
    "Untitled event" : "Esdeveniment sense títol",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha suprimit l'esdeveniment {event} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Heu suprimit l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha actualitzat l'esdeveniment {event} del calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} del calendari {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} ha desplaçat l'esdeveniment {event} del calendari {sourceCalendar} al calendari {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Heu desplaçat l'esdeveniment {event} del calendari {sourceCalendar} al calendari {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ha restaurat l'esdeveniment {event} del calendari {calendar}",
    "You restored event {event} of calendar {calendar}" : "Heu restaurat l'esdeveniment {event} del calendari {calendar}",
    "Busy" : "Ocupat",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} ha creat la tasca pendent {todo} en la llista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Heu creat la tasca pendent {todo} en la llista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} ha suprimit la tasca pendent {todo} de la llista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Heu suprimit la tasca pendent {todo} de la llista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} ha actualitzat la tasca pendent {todo} de la llista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Heu actualitzat la tasca pendent {todo} de la llista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} ha resolt la tasca pendent {todo} de la llista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Heu resolt la tasca pendent {todo} de la llista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} ha tornat a obrir la tasca pendent {todo} de la llista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Heu tornat a obrir la tasca pendent {todo} de la llista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} ha desplaçat la tasca pendent {todo} de la llista {sourceCalendar} a la llista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Heu desplaçat la tasca pendent {todo} de la llista {sourceCalendar} a la llista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendari, contactes i tasques",
    "A <strong>calendar</strong> was modified" : "S'ha modificat un <strong>calendari</strong>",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong>esdeveniment</strong> del calendari",
    "A calendar <strong>to-do</strong> was modified" : "S'ha modificat una <strong>tasca pendent</strong> del calendari",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Death of %s" : "Mort de %s",
    "Untitled calendar" : "Calendari sense títol",
    "Calendar:" : "Calendari:",
    "Date:" : "Data:",
    "Where:" : "Ubicació:",
    "Description:" : "Descripció:",
    "_%n year_::_%n years_" : ["%n any","%n anys"],
    "_%n month_::_%n months_" : ["%n mes","%n mesos"],
    "_%n day_::_%n days_" : ["%n dia","%n dies"],
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuts"],
    "%s (in %s)" : "%s (d'aquí a %s)",
    "%s (%s ago)" : "%s (fa %s)",
    "Calendar: %s" : "Calendari: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descripció: %s",
    "Where: %s" : "Ubicació: %s",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "In the past on %1$s for the entire day" : "En el passat a %1$s durant tot el dia",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["En una hora a %1$s durant tot el dia","En %n hores a %1$s durant tot el dia"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["En un dia a %1$s durant tot el dia","En %n dies a %1$s durant tot el dia"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["En una setmana a %1$s durant tot el dia","En %n setmanes a %1$s durant tot el dia"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["En un mes el %1$s durant tot el dia","En %n mesos el %1$s durant tot el dia"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["En un any a %1$s durant tot el dia","En %n anys a %1$s durant tot el dia"],
    "In the past on %1$s between %2$s - %3$s" : "En el passat el dia %1$s entre les %2$s i les %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["D'aquí a un minut el %1$s entre les %2$s i les %3$s","D’aquí a %n minuts el %1$s entre les %2$s i les %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["D'aquí a una hora el %1$s entre les %2$s i les %3$s","D’aquí a %n hores el %1$s entre les %2$s i les %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["En un dia el %1$s entre les %2$s i les %3$s","En %n dies el %1$s entre les %2$s i les %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["En una setmana el %1$s entre les %2$s i les %3$s","En %n setmanes el %1$s entre les %2$s i les %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["D'aquí a un mes el %1$s entre les %2$s i les %3$s","D’aquí a %n mesos el %1$s entre les %2$s i les %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["D'aquí a un any el %1$s entre les %2$s i les %3$s","D’aquí %n anys el %1$s entre les %2$s i les %3$s"],
    "Could not generate when statement" : "No s'ha pogut generar la declaració de quan",
    "Every Day for the entire day" : "Cada dia durant tot el dia",
    "Every Day for the entire day until %1$s" : "Cada dia durant tot el dia fins a les %1$s",
    "Every Day between %1$s - %2$s" : "Cada dia entre %1$s i %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Cada dia entre %1$s - %2$s fins a les %3$s",
    "Every %1$d Days for the entire day" : "Cada %1$d dies durant tot el dia",
    "Every %1$d Days for the entire day until %2$s" : "Cada %1$d dies durant tot el dia fins a les %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Cada %1$d dies entre %2$s i %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Cada %1$d dies entre les %2$s i les %3$s fins a les %4$s",
    "Could not generate event recurrence statement" : "No s'ha pogut generar la instrucció de recurrència de l'esdeveniment",
    "Every Week on %1$s for the entire day" : "Cada setmana el %1$s durant tot el dia",
    "Every Week on %1$s for the entire day until %2$s" : "Cada setmana el %1$s durant tot el dia fins a les %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Cada setmana el %1$s entre les %2$s i les %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Cada setmana el %1$s entre les %2$s i les %3$s fins a les %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Cada %1$d setmanes el dia %2$s durant tot el dia",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Cada %1$d setmanes el %2$s durant tot el dia fins a les %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Cada %1$d setmanes el dia %2$s entre les %3$s i les %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Cada %1$d setmanes el %2$s entre les %3$s i les %4$s fins a les %5$s",
    "Every Month on the %1$s for the entire day" : "Cada mes a les %1$s durant tot el dia",
    "Every Month on the %1$s for the entire day until %2$s" : "Cada mes a les %1$s durant tot el dia fins a les %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Cada mes el %1$s entre les %2$s i les %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Cada mes el dia %1$s entre les %2$s i les %3$s fins a les %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Cada %1$d mesos el %2$s durant tot el dia",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Cada %1$d mesos el %2$s durant tot el dia fins a les %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Cada %1$d mesos el %2$s entre les %3$s i les %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Cada %1$d mesos el %2$s entre les %3$s i les %4$s fins a les %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Cada any a %1$s el %2$s durant tot el dia",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Cada any a %1$s el %2$s durant tot el dia fins a les %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Cada any a %1$s el %2$s entre les %3$s i les %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Cada any a %1$s el %2$s entre les %3$s i les %4$s fins a %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Cada %1$d anys a %2$s el %3$s durant tot el dia",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Cada %1$d anys a %2$s el %3$s durant tot el dia fins a les %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Cada %1$d anys a %2$s el %3$s entre les %4$s i les %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Cada %1$d anys a %2$s el %3$s entre les %4$s i les %5$s fins a %6$s",
    "On specific dates for the entire day until %1$s" : "En dates específiques durant tot el dia fins a les %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "En dates específiques entre les %1$s i les %2$s fins a %3$s",
    "In the past on %1$s" : "En el passat a %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["D'aquí a una hora a %1$s","D’aquí %n hores a %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["En un dia el %1$s","En %n dies el %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["D'aquí a una setmana el %1$s","D’aquí %n setmanes el %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["D'aquí a un mes el %1$s","D’aquí %n mesos el %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["D'aquí a un any el %1$s","D’aquí %n anys el %1$s"],
    "In the past on %1$s then on %2$s" : "En el passat el %1$s i després el %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["D'aquí a un minut el %1$s i després el %2$s","D’aquí a %n minuts el %1$s i després el %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["D'aquí a una hora el %1$s i després el %2$s","D’aquí %n hores el %1$s i després el %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["En un dia el %1$s i després el %2$s","En %n dies el %1$s i després el %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["D'aquí a una setmana el %1$s i després el %2$s","D’aquí %n setmanes el %1$s i després el %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["D'aquí a un mes el %1$s i després el %2$s","D’aquí %n mesos el %1$s i després el %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["D'aquí a un any el %1$s i després el %2$s","D’aquí %n anys el %1$s i després el %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "En el passat el %1$s, després el %2$s i el %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["D'aquí a un minut el %1$s i després el %2$s i el %3$s","D’aquí a %n minuts el %1$s i després el %2$s i el %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["D'aquí a una hora el %1$s i després el %2$s i el %3$s","D’aquí a %n hores el %1$s i després el %2$s i el %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["D'aquí a un dia el %1$s i després el %2$s i el %3$s","D’aquí a %n dies el %1$s i després el %2$s i el %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["D'aquí a una setmana el %1$s i després el %2$s i el %3$s","D’aquí a %n setmanes el %1$s i després el %2$s i el %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["D'aquí a un mes el %1$s i després el %2$s i el %3$s","D’aquí a %n mesos el %1$s i després el %2$s i el %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["D'aquí a un any el %1$s i després el %2$s i el %3$s","D’aquí a %n anys el %1$s i després el %2$s i el %3$s"],
    "Could not generate next recurrence statement" : "No s'ha pogut generar la següent instrucció de recurrència",
    "Cancelled: %1$s" : "S'ha cancel·lat: %1$s",
    "\"%1$s\" has been canceled" : "S'ha cancel·lat «%1$s»",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s ha acceptat la vostra invitació",
    "%1$s has tentatively accepted your invitation" : "%1$s ha acceptat provisionalment la vostra invitació",
    "%1$s has declined your invitation" : "%1$s ha rebutjat la vostra invitació",
    "%1$s has responded to your invitation" : "%1$s ha respost a la vostra invitació",
    "Invitation updated: %1$s" : "S'ha actualitzat la invitació: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s ha actualitzat l'esdeveniment «%2$s»",
    "Invitation: %1$s" : "Invitació: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vol convidar-vos a «%2$s»",
    "Organizer:" : "Organització:",
    "Attendees:" : "Assistents:",
    "Title:" : "Títol:",
    "When:" : "Quan:",
    "Location:" : "Ubicació:",
    "Link:" : "Enllaç:",
    "Occurring:" : "Ocorrent:",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "More options …" : "Més opcions…",
    "More options at %s" : "Més opcions a %s",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Diumenge",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "First" : "Primer",
    "Second" : "Segon",
    "Third" : "Tercer",
    "Fourth" : "Quart",
    "Fifth" : "Cinquè",
    "Last" : "Últim",
    "Second Last" : "Segon últim",
    "Third Last" : "Tercer últim",
    "Fourth Last" : "Quart últim",
    "Fifth Last" : "Cinquè últim",
    "Contacts" : "Contactes",
    "{actor} created address book {addressbook}" : "{actor} ha creat la llibreta d'adreces {addressbook}",
    "You created address book {addressbook}" : "Heu creat la llibreta d'adreces {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ha suprimit la llibreta d'adreces {addressbook}",
    "You deleted address book {addressbook}" : "Heu suprimit la llibreta d'adreces {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ha actualitzat la llibreta d'adreces {addressbook}",
    "You updated address book {addressbook}" : "Heu actualitzat la llibreta d'adreces {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb vós",
    "You shared address book {addressbook} with {user}" : "Heu compartit la llibreta d'adreces {addressbook} amb {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb vós",
    "You unshared address book {addressbook} from {user}" : "Heu deixat de compartir la llibreta d'adreces {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb si mateix",
    "You shared address book {addressbook} with group {group}" : "Heu compartit la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb el grup {group}",
    "You unshared address book {addressbook} from group {group}" : "Heu deixat de compartir la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creat el contacte {card} en la llibreta d'adreces {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Heu creat el contacte {card} en la llibreta d'adreces {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha suprimit el contacte {card} de la llibreta d'adreces {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Heu suprimit el contacte {card} de la llibreta d'adreces {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha actualitzat el contacte {card} de la llibreta d'adreces {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Heu actualitzat el contacte {card} de la llibreta d'adreces {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "S'ha modificat un <strong>contacte</strong> o una <strong>llibreta d'adreces</strong>",
    "Accounts" : "Comptes",
    "System address book which holds all accounts" : "Llibreta d'adreces del sistema que conté tots els comptes",
    "File is not updatable: %1$s" : "El fitxer no es pot actualitzar: %1$s",
    "Failed to get storage for file" : "No s'ha pogut obtenir emmagatzematge per al fitxer",
    "Could not write to final file, canceled by hook" : "No s'ha pogut escriure el fitxer final perquè el ganxo ho ha cancel·lat",
    "Could not write file contents" : "No s'ha pogut escriure el contingut del fitxer",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "S'ha produït un error en copiar el fitxer a la ubicació de destinació (dades copiades: %1$s, mida esperada del fitxer: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "S'esperava una mida de fitxer de %1$s, però s'han llegit (des del client del Nextcloud) i s'han escrit (a l'emmagatzematge del Nextcloud) %2$s. Pot ser un problema de xarxa del costat d'enviament o un problema d'escriptura a l'emmagatzematge del costat del servidor.",
    "Could not rename part file to final file, canceled by hook" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final perquè el ganxo ho ha cancel·lat",
    "Could not rename part file to final file" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final",
    "Failed to check file size: %1$s" : "No s'ha pogut comprovar la mida del fitxer: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, el fitxer sembla que existeix",
    "Could not open file: %1$s, file doesn't seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, sembla que el fitxer no existeix",
    "Encryption not ready: %1$s" : "El xifratge no està preparat: %1$s",
    "Failed to open file: %1$s" : "No s'ha pogut obrir el fitxer: %1$s",
    "Failed to unlink: %1$s" : "No s'ha pogut desenllaçar: %1$s",
    "Failed to write file contents: %1$s" : "No s'ha pogut escriure el contingut del fitxer: %1$s",
    "File not found: %1$s" : "No s'ha trobat el fitxer: %1$s",
    "Invalid target path" : "Camí de destinació no vàlid",
    "System is in maintenance mode." : "El sistema és en mode de manteniment.",
    "Upgrade needed" : "Cal actualitzar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Cal que configureu el %s perquè utilitzi HTTPS per a poder utilitzar CalDAV i CardDAV amb l'iOS/macOS.",
    "Configures a CalDAV account" : "Configura un compte CalDAV",
    "Configures a CardDAV account" : "Configura un compte CardDAV",
    "Events" : "Esdeveniments",
    "Untitled task" : "Tasca sense títol",
    "Completed on %s" : "Completada el %s",
    "Due on %s by %s" : "Venç el %s a les %s",
    "Due on %s" : "Venç el %s",
    "System Address Book" : "Llibreta d'adreces del sistema",
    "The system address book contains contact information for all users in your instance." : "La llibreta d'adreces del sistema conté informació de contacte de tots els usuaris de la vostra instància.",
    "Enable System Address Book" : "Habilita la llibreta d'adreces del sistema",
    "DAV system address book" : "Llibreta d'adreces del sistema DAV",
    "No outstanding DAV system address book sync." : "No hi ha cap sincronització pendent de la llibreta d'adreces del sistema DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronització de la llibreta d'adreces del sistema DAV encara no s'ha executat perquè la instància té més de 1000 usuaris o a causa d'un error. Executeu-la manualment amb «occ dav:sync-system-addressbook».",
    "WebDAV endpoint" : "Extrem WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "No s'ha pogut comprovar que el vostre servidor web estigui configurat correctament per a permetre la sincronització de fitxers mitjançant WebDAV. Comproveu-ho manualment.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "El vostre servidor web no està configurat correctament per a permetre la sincronització de fitxers perquè sembla que la interfície WebDAV no funciona correctament.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "El vostre servidor web està configurat correctament per a permetre la sincronització de fitxers mitjançant WebDAV.",
    "Migrated calendar (%1$s)" : "Calendari migrat (%1$s)",
    "Calendars including events, details and attendees" : "Calendaris amb esdeveniments, detalls i assistents",
    "Contacts and groups" : "Contactes i grups",
    "WebDAV" : "WebDAV",
    "Absence saved" : "S'ha desat l'absència",
    "Failed to save your absence settings" : "No s'han pogut desar els paràmetres de l'absència",
    "Absence cleared" : "S'ha esborrat l'absència",
    "Failed to clear your absence settings" : "No s'han pogut esborrar els paràmetres de l'absència",
    "First day" : "Primer dia",
    "Last day (inclusive)" : "Darrer dia (inclòs)",
    "Out of office replacement (optional)" : "Substitució fora de l'oficina (opcional)",
    "Name of the replacement" : "Nom del substitut",
    "No results." : "Cap resultat.",
    "Start typing." : "Comença a escriure.",
    "Short absence status" : "Estat d'absència breu",
    "Long absence Message" : "Missatge d'absència llarga",
    "Save" : "Desa",
    "Disable absence" : "Inhabilita l'absència",
    "Failed to load availability" : "No s'ha pogut carregar la disponibilitat",
    "Saved availability" : "S'ha desat la disponibilitat",
    "Failed to save availability" : "No s'ha pogut desar la disponibilitat",
    "Time zone:" : "Fus horari:",
    "to" : "a",
    "Delete slot" : "Suprimeix la franja",
    "No working hours set" : "No s'ha definit cap horari laboral",
    "Add slot" : "Afegeix una franja",
    "Weekdays" : "Dies de la setmana",
    "Pick a start time for {dayName}" : "Trieu una hora d'inici per a {dayName}",
    "Pick a end time for {dayName}" : "Trieu una hora de finalització per a {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Estableix automàticament l'estat de l'usuari com a \"No molesteu” fora de la disponibilitat per a silenciar totes les notificacions.",
    "Availability" : "Disponibilitat",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta de persones veuran quan sou fora de l'oficina quan planifiquin una reunió.",
    "Absence" : "Absència",
    "Configure your next absence period." : "Configureu el pròxim període d'absència.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal·leu també {calendarappstoreopen}l'aplicació Calendari{linkclose} o {calendardocopen}connecteu el vostre dispositiu d'escriptori i el mòbil per a sincronitzar-los ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assegureu-vos de configurar correctament el{emailopen}servidor de correu electrònic{linkclose}.",
    "Calendar server" : "Servidor de calendari",
    "Send invitations to attendees" : "Envia invitacions als assistents",
    "Automatically generate a birthday calendar" : "Genera automàticament un calendari d’aniversaris",
    "Birthday calendars will be generated by a background job." : "Un procés en segon pla generarà els calendaris d'aniversaris.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per tant, no estaran disponibles immediatament després d'habilitar-los, però apareixeran després d'una estona.",
    "Send notifications for events" : "Envia notificacions per als esdeveniments",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notificacions les envien feines en segon pla, de manera que han d'ocórrer prou sovint.",
    "Send reminder notifications to calendar sharees as well" : "Envia també notificacions de recordatori als usuaris amb qui s'ha compartit el calendari",
    "Reminders are always sent to organizers and attendees." : "Sempre s'envien recordatoris als organitzadors i als assistents.",
    "Enable notifications for events via push" : "Habilita les notificacions automàtiques per als esdeveniments",
    "Cancel" : "Cancel·la",
    "Import" : "Importa",
    "Error while saving settings" : "S'ha produït un error en desar els paràmetres",
    "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat d'assistència.",
    "Please contact the organizer directly." : "Contacteu amb l'organització directament.",
    "Are you accepting the invitation?" : "Accepteu la invitació?",
    "Tentative" : "Provisional",
    "Your attendance was updated successfully." : "S'ha actualitzat correctament l'assistència.",
    "Time:" : "Hora:",
    "Could not open file" : "No s'ha pogut obrir el fitxer",
    "Invalid chunk name" : "El nom del fragment no és vàlid",
    "Could not rename part file assembled from chunks" : "No s'ha pogut canviar el nom del fitxer de part muntat a partir de fragments"
},
"nplurals=2; plural=(n != 1);");
